#
# spec file for package ghc-amazonka-iam
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name amazonka-iam
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.3
Release:        7.11
Summary:        Amazon Identity and Access Management SDK
License:        MPL-2.0
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-amazonka-core-devel
BuildRequires:  ghc-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-amazonka-test-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
%endif

%description
AWS Identity and Access Management AWS Identity and Access Management (IAM) is
a web service that you can use to manage users and user permissions under your
AWS account. This guide provides descriptions of IAM actions that you can call
programmatically. For general information about IAM, see
<http://aws.amazon.com/iam/ AWS Identity and Access Management (IAM)>.
For the user guide for IAM, see
<http://docs.aws.amazon.com/IAM/latest/UserGuide/ Using IAM>. AWS provides SDKs
that consist of libraries and sample code for various programming languages and
platforms (Java, Ruby, .NET, iOS, Android, etc.). The SDKs provide a convenient
way to create programmatic access to IAM and AWS. For example, the SDKs take
care of tasks such as cryptographically signing requests (see below), managing
errors, and retrying requests automatically. For information about the AWS
SDKs, including how to download and install them, see the
<http://aws.amazon.com/tools/ Tools for Amazon Web Services> page. We recommend
that you use the AWS SDKs to make programmatic API calls to IAM.
However, you can also use the IAM Query API to make direct calls to the IAM web
service. To learn more about the IAM Query API, see
<http://docs.aws.amazon.com/IAM/latest/UserGuide/IAM_UsingQueryAPI.html Making
Query Requests> in the /Using IAM/ guide. IAM supports GET and POST requests
for all actions. That is, the API does not require you to use GET for some
actions and POST for others. However, GET requests are subject to the
limitation size of a URL. Therefore, for operations that require larger sizes,
use a POST request. __Signing Requests__ Requests must be signed using an
access key ID and a secret access key. We strongly recommend that you do not
use your AWS account access key ID and secret access key for everyday work with
IAM. You can use the access key ID and secret access key for an IAM user or you
can use the AWS Security Token Service to generate temporary security
credentials and use those to sign requests. To sign requests, we recommend that
you use <http://docs.aws.amazon.com/general/latest/gr/signature-version-4.html
Signature Version 4>. If you have an existing application that uses Signature
Version 2, you do not have to update it to use Signature Version 4.
However, some operations now require Signature Version 4. The documentation for
operations that require version 4 indicate this requirement.
__Additional Resources__ For more information, see the following: -
<http://docs.aws.amazon.com/general/latest/gr/aws-security-credentials.html AWS
Security Credentials>. This topic provides general information about the types
of credentials used for accessing AWS. -
<http://docs.aws.amazon.com/IAM/latest/UserGuide/IAMBestPractices.html IAM Best
Practices>. This topic presents a list of suggestions for using the IAM service
to help secure your AWS resources. -
<http://docs.aws.amazon.com/general/latest/gr/signing_aws_api_requests.html
Signing AWS API Requests>. This set of topics walk you through the process of
signing a request using an access key ID and secret access key.

The types from this library are intended to be used with
<http://hackage.haskell.org/package/amazonka amazonka>, which provides
mechanisms for specifying AuthN/AuthZ information and sending requests.

Use of lenses is required for constructing and manipulating types.
This is due to the amount of nesting of AWS types and transparency regarding
de/serialisation into more palatable Haskell values. The provided lenses should
be compatible with any of the major lens libraries such as
<http://hackage.haskell.org/package/lens lens> or
<http://hackage.haskell.org/package/lens-family-core lens-family-core>.

See "Network.AWS.IAM" or <https://aws.amazon.com/documentation/ the AWS
Documentation> to get started.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.4.3 revision 0 with cabal2obs.
